@@ -18,6 +18,7 @@
 ## OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 ## THE SOFTWARE.
 
+import os
 import sys
 import json
 import hmac
@@ -31,9 +32,10 @@ import config
 import utils
 import remote
 import local
+import https
 
 
-VERSION = '0.2.4'
+VERSION = '0.2.5'
 
 
 def hook_setup(cmd):
@@ -72,6 +74,7 @@ def run_remote(cmd):
             'set_url': r.set_url,
             'run': r.run,
             'script': r.run_script,
+            'sftp': r.sftp,
             'pull': r.pull,
             'push': r.push,
             'rsync': r.rsync,
@@ -82,7 +85,8 @@ def run_remote(cmd):
             'call': lambda x: run_command(x, True),
             'echo': lambda x: sys.stdout.write('{0}\n'.format(x)),
             'echo_error': lambda x: sys.stderr.write('{0}\n'.format(x)),
-            'set_verbose': r.set_verbose
+            'set_verbose': r.set_verbose,
+            'key': r.key
             }
     for args in cmd:
         c = args[0]
@@ -112,10 +116,16 @@ def sign_request(api_key, method, request):
     return headers
 
 def run_command(cmd, internal=False):
+    if internal is False and not os.path.exists(
+            os.path.join(config.CONFIG_DIR, 'dotcloud.key')):
+        run_command('get_key', True)
     data = None
     cfg = config.load_user_config()
     url = utils.parse_url(cfg.url)
-    req = httplib.HTTPConnection(url['host'], int(url['port'] or 80))
+    if url['scheme'].lower() == 'https':
+        req = https.HTTPSConnection(url['host'], int(url['port'] or 443))
+    else:
+        req = httplib.HTTPConnection(url['host'], int(url['port'] or 80))
     cmd = urllib.quote(json.dumps(cmd))
     query = '{0}run?{1}={2}'.format(url['path'], 'c' if internal is True else 'q', cmd)
     headers = sign_request(cfg.apikey, 'GET', query)
