@@ -20,17 +20,32 @@
 
 from setuptools import setup
 
-VERSION = '0.2.4'
+VERSION = '0.2.5'
 
 # rm -rf build dist *.egg-info && python ./setup.py clean sdist upload -r pypi
 
 setup(
         name                = 'dotcloud',
         version             = VERSION,
-        author              = 'DotCloud inc.',
+        author              = 'dotCloud Inc.',
         author_email        = 'support@dotcloud.com',
-        url                 = 'http://www.dotcloud.com',
-        description         = 'DotCloud command line interface',
+        url                 = 'http://www.dotcloud.com/',
+        description         =
+        'dotCloud meta-package to automatically install the dotCloud CLI',
+        long_description    =
+        'This package does not provide anything per se. It contains a single '
+        'dependency on dotcloud.cli, the CLI allowing to manage your '
+        'software deployments on the dotCloud platform.'
+        '\n'
+        'Using dotCloud, you can assemble your stack from pre-configured and '
+        'heavily tested components. dotCloud supports major application '
+        'servers, databases and message buses. '
+        '\n'
+        'The dotCloud CLI allows you to manage your software deployments on '
+        'the dotCloud platform. To use this tool, you will need a dotCloud '
+        'account. Register at http://www.dotcloud.com/ to get one!',
+        package_dir         = {'dotcloud': '.'},
+        packages            = ['dotcloud'],
         install_requires    = ['dotcloud.cli >= {0}'.format(VERSION)],
         zip_safe            = False
 )
